Struct SubsetBuilder
pub struct SubsetBuilder { /* private fields */ }Implementations
impl SubsetBuilder
impl SubsetBuilder
pub fn new() -> SubsetBuilder
pub fn pad_to_len(&mut self, total_len: usize)
pub fn pad_to_len(&mut self, total_len: usize)
Intended for use with add_range to ensure the total length of the
Subset corresponds to the document length.
pub fn add_range(&mut self, begin: usize, end: usize, count: usize)
pub fn add_range(&mut self, begin: usize, end: usize, count: usize)
Sets the count for a given range. This method must be called with a
non-empty range with begin not before the largest range or segment added
so far. Gaps will be filled with a 0-count segment.
pub fn push_segment(&mut self, len: usize, count: usize)
pub fn push_segment(&mut self, len: usize, count: usize)
Assign count to the next len elements in the string.
Will panic if called with len==0.
pub fn build(self) -> Subset