Struct Mapper
pub struct Mapper<'a> {
pub subset_amount_consumed: usize,
/* private fields */
}Fields
subset_amount_consumed: usizeImplementations
impl<'a> Mapper<'a>
impl<'a> Mapper<'a>
pub fn doc_index_to_subset(&mut self, i: usize) -> usize
pub fn doc_index_to_subset(&mut self, i: usize) -> usize
Map a coordinate in the document this subset corresponds to, to a
coordinate in the subset matched by the CountMatcher. For example,
if the Subset is a set of deletions and the matcher is
CountMatcher::NonZero, this would map indices in the union string to
indices in the tombstones string.
Will return the closest coordinate in the subset if the index is not in the subset. If the coordinate is past the end of the subset it will return one more than the largest index in the subset (i.e the length). This behaviour is suitable for mapping closed-open intervals in a string to intervals in a subset of the string.
In order to guarantee good performance, this method must be called
with i values in non-decreasing order or it will panic. This allows
the total cost to be O(n) where n = max(calls,ranges) over all times
called on a single Mapper.